Orchestral Context
Context abstraction and assembly layer for Orchestral. Provides a unified view over events and artifacts (text/image/file/etc.).
Structs
- Basic
Context Builder - Basic context builder (rule-based, no LLM summarization)
- Context
Builder Config - Context builder configuration
- Context
Request - Context request input
- Context
Slice - A single context slice included in a context window
- Context
Window - Assembled context window
- Thread
Summary - Thread-level summary artifact.
- Token
Budget - Token budget for context assembly
Enums
- Context
Error - Context builder errors
Traits
- Context
Builder - Context builder trait
- Thread
Summarizer - Pluggable thread summary strategy.