pub struct GenericModelContextTrace {
pub through_session_seq: u64,
pub included_ranges: Vec<SessionSourceRange>,
pub deferred_ranges: Vec<SessionSourceRange>,
pub config_digest: Digest,
pub history_limit: usize,
pub used_input_tokens: u64,
pub context_estimate: Option<ModelContextEstimate>,
pub planning: Option<ContextPlanningTrace>,
pub input_budget_tokens: u64,
}Expand description
Durable provenance for the exact Session Context projected before one model attempt. The request digest proves bytes; this trace explains which Journal ranges and Host limits produced those bytes.
Fields
through_session_seq: u64included_ranges: Vec<SessionSourceRange>deferred_ranges: Vec<SessionSourceRange>config_digest: Digesthistory_limit: usizeused_input_tokens: u64context_estimate: Option<ModelContextEstimate>planning: Option<ContextPlanningTrace>input_budget_tokens: u64Trait Implementations
Sourceimpl Clone for GenericModelContextTrace
impl Clone for GenericModelContextTrace
Sourcefn clone(&self) -> GenericModelContextTrace
fn clone(&self) -> GenericModelContextTrace
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GenericModelContextTrace
impl Debug for GenericModelContextTrace
Sourceimpl<'de> Deserialize<'de> for GenericModelContextTrace
impl<'de> Deserialize<'de> for GenericModelContextTrace
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for GenericModelContextTrace
Sourceimpl PartialEq for GenericModelContextTrace
impl PartialEq for GenericModelContextTrace
Sourceimpl Serialize for GenericModelContextTrace
impl Serialize for GenericModelContextTrace
impl StructuralPartialEq for GenericModelContextTrace