pub struct SkillCatalog { /* private fields */ }Implementations
Sourceimpl SkillCatalog
impl SkillCatalog
pub fn new(entries: Vec<SkillEntry>, max_active: usize) -> Self
pub fn entries(&self) -> &[SkillEntry]
pub fn active_entries(&self) -> Vec<&SkillEntry>
Sourcepub fn reload(&mut self, entries: Vec<SkillEntry>)
pub fn reload(&mut self, entries: Vec<SkillEntry>)
Reload entries from filesystem (hot update).
Sourcepub fn summaries(&self) -> Vec<(&str, &str)>
pub fn summaries(&self) -> Vec<(&str, &str)>
Return all skill names and descriptions for the planner catalog.
Sourcepub fn get_instructions(&self, name: &str) -> Option<SkillInstruction>
pub fn get_instructions(&self, name: &str) -> Option<SkillInstruction>
Look up a skill by exact name and return its full instructions.
pub fn build_instructions(&self, intent: &str) -> Vec<SkillInstruction>