pub struct RuntimeApp {
pub orchestrator: Orchestrator,
pub blob_store: Arc<dyn BlobStore>,
pub hook_registry: Arc<HookRegistry>,
pub action_registry_manager: Arc<ActionRegistryManager>,
}Expand description
Running app bundle created from unified config.
Fields
orchestrator: Orchestratorblob_store: Arc<dyn BlobStore>hook_registry: Arc<HookRegistry>action_registry_manager: Arc<ActionRegistryManager>Implementations
Sourceimpl RuntimeApp
impl RuntimeApp
Sourcepub async fn from_config_path(
path: impl Into<PathBuf>,
) -> Result<Self, BootstrapError>
pub async fn from_config_path( path: impl Into<PathBuf>, ) -> Result<Self, BootstrapError>
Create a runnable app from a single orchestral.yaml.
Sourcepub async fn from_config_path_with_component_factory(
path: impl Into<PathBuf>,
component_factory: Arc<dyn RuntimeComponentFactory>,
) -> Result<Self, BootstrapError>
pub async fn from_config_path_with_component_factory( path: impl Into<PathBuf>, component_factory: Arc<dyn RuntimeComponentFactory>, ) -> Result<Self, BootstrapError>
Create a runnable app and inject custom runtime component factory.
Sourcepub async fn from_config_path_with_spi(
path: impl Into<PathBuf>,
component_factory: Arc<dyn RuntimeComponentFactory>,
hook_registry: Arc<HookRegistry>,
action_factory: Arc<dyn ActionFactory>,
) -> Result<Self, BootstrapError>
pub async fn from_config_path_with_spi( path: impl Into<PathBuf>, component_factory: Arc<dyn RuntimeComponentFactory>, hook_registry: Arc<HookRegistry>, action_factory: Arc<dyn ActionFactory>, ) -> Result<Self, BootstrapError>
Create a runnable app and inject component factory + hook registry.