pub struct FrozenToolObservations(/* private fields */);Expand description
Verified before any Tool in the current response is executed. Its private contents cannot gain a newly committed read during that batch.