pub struct ModelToolObservations(/* private fields */);Expand description
Successful Tool values present in the exact request sent to a model. Construct this before executing that response’s Tool batch: a read from the same batch has not yet been observed by the model and is ineligible.
Implementations
Sourceimpl ModelToolObservations
impl ModelToolObservations
pub fn from_messages(messages: &[ModelMessage]) -> Self