pub trait GenericAgentCheckpointStore: Send + Sync {
// Required methods
fn load_run(
&self,
run_id: &RunId,
) -> Result<Option<StoredGenericAgentRun>, GenericCheckpointError>;
fn create_run(
&self,
registration: GenericAgentRunRegistration,
) -> Result<CreateGenericRunOutcome, GenericCheckpointError>;
fn append(
&self,
run_id: &RunId,
expected_previous: u64,
draft: GenericCheckpointDraft,
) -> Result<AppendGenericCheckpointOutcome, GenericCheckpointError>;
}Expand description
Synchronous metadata WAL used on the Generic Agent’s existing commit critical sections. Implementations must keep records small and must not do heavyweight parsing, embedding, or remote work in this call path.
Required Methods
fn load_run( &self, run_id: &RunId, ) -> Result<Option<StoredGenericAgentRun>, GenericCheckpointError>
fn create_run( &self, registration: GenericAgentRunRegistration, ) -> Result<CreateGenericRunOutcome, GenericCheckpointError>
fn append( &self, run_id: &RunId, expected_previous: u64, draft: GenericCheckpointDraft, ) -> Result<AppendGenericCheckpointOutcome, GenericCheckpointError>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".