pub struct ExecutorContext {
pub working_set: Arc<RwLock<WorkingSet>>,
pub workflow_id: WorkflowId,
pub cancellation_token: CancellationToken,
pub progress_reporter: Option<Arc<dyn ExecutionProgressReporter>>,
pub step_execution_port: Arc<dyn StepExecutionPort>,
}Expand description
Executor context
Fields
working_set: Arc<RwLock<WorkingSet>>Working set for inter-step communication
workflow_id: WorkflowIdTask ID
cancellation_token: CancellationTokenRoot cancellation token for this execution.
Every action receives a child of this token so cancelling the execution is propagated without allowing one action to cancel its siblings.
progress_reporter: Option<Arc<dyn ExecutionProgressReporter>>Optional execution progress reporter.
step_execution_port: Arc<dyn StepExecutionPort>Host-owned execution boundary for this Run. It is mandatory so the DAG cannot fall back to an unguarded Action or nested Agent executor.
Implementations
Sourceimpl ExecutorContext
impl ExecutorContext
Sourcepub fn new(
workflow_id: impl Into<WorkflowId>,
working_set: Arc<RwLock<WorkingSet>>,
step_execution_port: Arc<dyn StepExecutionPort>,
) -> ExecutorContext
pub fn new( workflow_id: impl Into<WorkflowId>, working_set: Arc<RwLock<WorkingSet>>, step_execution_port: Arc<dyn StepExecutionPort>, ) -> ExecutorContext
Create a new executor context
Sourcepub fn with_cancellation_token(
self,
cancellation_token: CancellationToken,
) -> ExecutorContext
pub fn with_cancellation_token( self, cancellation_token: CancellationToken, ) -> ExecutorContext
Attach the root cancellation token owned by the execution caller.
Sourcepub fn with_progress_reporter(
self,
reporter: Arc<dyn ExecutionProgressReporter>,
) -> ExecutorContext
pub fn with_progress_reporter( self, reporter: Arc<dyn ExecutionProgressReporter>, ) -> ExecutorContext
Attach a realtime execution progress reporter.